====
Jobs
====

.. autosummary::
    :toctree: api/
    :template: ../../../../_templates/class_template.rst

    prismstudio.job_manager
    prismstudio.list_job
    prismstudio.get_job
    prismstudio.delete_job
    prismstudio.cancel_job
    prismstudio.prioritise_job
    .. prismstudio.screen.list_job
    .. prismstudio.factor_backtest.list_job
    .. prismstudio.export_data.list_job
    .. prismstudio.extract_job
